@@ -96,7 +96,7 @@ check_var <- function(vars, varn, varntype = NULL, dataset,
       if (any(names(vars) == namesID1)) setnames(vars, names(vars), paste0(names(vars), "_", varn))
 
       if (use.gender & varn %in% c("years", "yearsX")){
-                parb <- unique(substr(vars[[1]], nchar(vars[[1]])-1, nchar(vars[[1]])))
+                parb <- unique(substring(vars[[1]], nchar(vars[[1]])-1, nchar(vars[[1]])))
                 if (!all(parb %in% c("_1", "_2")) | length(parb) != 2) {
                      stop(paste0("'", varn, "' must be ended with '_1' and '_2'"), call. = FALSE) }}
 
