@@ -20,10 +20,10 @@ linqsr <- function(Y, id = NULL, weight = NULL,
    if (min(dim(as.data.frame(var_name)) == 1) != 1) {
        stop("'var_name' must have defined name of the linearized variable")}
 
-   if(length(alpha) != 1 | any(!is.numeric(alpha) | alpha < 0 | alpha > 100)) {
-          stop("'alpha' must be a numeric value in [0, 100]")  }
-
   if (checking) {
+         alpha <- check_var(vars = alpha, varn = "alpha",
+                            varntype = "numeric0100")
+
          Y <- check_var(vars = Y, varn = "Y", dataset = dataset,
                         ncols = 1, isnumeric = TRUE,
                         isvector = TRUE, grepls = "__")
