@@ -133,7 +133,7 @@ vardchangespoor <- function(Y, age = NULL,
                         check.names = TRUE, isnumeric = TRUE,
                         dif_name = c(names(period), names(country), names(H),
                                      names(PSU), names(ID_level1), "w_final",
-                                     "w_design", "g", "q"))
+                                     "w_design", "g", "q"), dX = "X")
          Xnrow <- nrow(X)
     
          ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
@@ -141,21 +141,21 @@ vardchangespoor <- function(Y, age = NULL,
                              Xnrow = Xnrow, ischaracter = TRUE, 
                              dif_name = c(names(period), names(country), names(H),
                                           names(PSU), names(ID_level1), "w_final",
-                                          "w_design", "g", "q"))
+                                          "w_design", "g", "q"), dX = "X")
     
          g <- check_var(vars = g, varn = "g", dataset = datasetX,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                        isvector = TRUE)
+                        isvector = TRUE, dX = "X")
        
          q <- check_var(vars = q, varn = "q", dataset = datasetX,
                         ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                        isvector = TRUE)
+                        isvector = TRUE, dX = "X")
      
          countryX <- check_var(vars = countryX, varn = "countryX",
                                dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                                ischaracter = TRUE, mustbedefined = !is.null(country),
                                varnout = "country", varname = names(country),
-                               country = country)
+                               country = country, dX = "X")
     
          periodX <- check_var(vars = periodX, varn = "periodX",
                               dataset = datasetX, ncols = 1, 
@@ -163,14 +163,14 @@ vardchangespoor <- function(Y, age = NULL,
                               mustbedefined = !is.null(period),
                               duplicatednames = TRUE, varnout = "period",
                               varname = names(period), country = country,
-                              countryX = countryX, periods = period)
+                              countryX = countryX, periods = period, dX = "X")
     
          X_ID_level1 <- check_var(vars = X_ID_level1, varn = "X_ID_level1",
                                   dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                                   ischaracter = TRUE, varnout = "ID_level1",
                                   varname = names(ID_level1), country = country,
                                   countryX = countryX, periods = period,
-                                  periodsX = periodX, ID_level1 = ID_level1)
+                                  periodsX = periodX, ID_level1 = ID_level1, dX = "X")
      } 
 
   if (is.null(Y_thres)) Y_thres <- Y
@@ -365,8 +365,9 @@ vardchangespoor <- function(Y, age = NULL,
                                "type", "estim_1", "estim_2",
                                "estim", "var", "se",
                                "CI_lower", "CI_upper"), with = FALSE]
-   data <- NULL
+   data <- confidence_level <- NULL
 
+   changes_results[, confidence_level := confidence]
    changes_results[, significant := TRUE]
    boundss <- as.numeric(change_type == "relative")
    changes_results[CI_lower <= boundss & CI_upper >= boundss, significant := FALSE]
