@@ -122,7 +122,7 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                              check.names = TRUE, isnumeric = TRUE,
                              dif_name = c(names(period), names(country), names(H),
                                            names(PSU), names(ID_level1), "w_final",
-                                           "w_design", "g", "q"))
+                                           "w_design", "g", "q"), dX = "X")
               Xnrow <- nrow(X)
            
            
@@ -131,21 +131,21 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                                  Xnrow = Xnrow, ischaracter = TRUE,
                                  dif_name = c(names(period), names(country), names(H),
                                               names(PSU), names(ID_level1), "w_final",
-                                              names(X), "w_design", "g", "q"))
+                                              names(X), "w_design", "g", "q"), dX = "X")
            
              g <- check_var(vars = g, varn = "g", dataset = datasetX,
                             ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                            isvector = TRUE)
+                            isvector = TRUE, dX = "X")
            
              q <- check_var(vars = q, varn = "q", dataset = datasetX,
                             ncols = 1, Xnrow = Xnrow, isnumeric = TRUE,
-                             isvector = TRUE)
+                             isvector = TRUE, dX = "X")
            
              countryX <- check_var(vars = countryX, varn = "countryX",
                                    dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                                    ischaracter = TRUE, mustbedefined = !is.null(country),
                                    varnout = "country", varname = names(country),
-                                   country = country)
+                                   country = country, dX = "X")
             
              periodX <- check_var(vars = periodX, varn = "periodX",
                                   dataset = datasetX, ncols = 1,
@@ -153,13 +153,13 @@ vardcrospoor <- function(Y, age = NULL, pl085 = NULL,
                                   mustbedefined = !is.null(period),
                                   duplicatednames = TRUE, varnout = "period",
                                   varname = names(period), country = country,
-                                  countryX = countryX, periods = period)
+                                  countryX = countryX, periods = period, dX = "X")
            
              X_ID_level1 <- check_var(vars = X_ID_level1, varn = "X_ID_level1",
                                       dataset = datasetX, ncols = 1, Xnrow = Xnrow,
                                       ischaracter = TRUE, varnout = "ID_level1",
                                       varname = names(ID_level1), country = country,
-                                      countryX = countryX, periods = period,
+                                      countryX = countryX, periods = period, dX = "X",
                                       periodsX = periodX, ID_level1 = ID_level1)            
           }
      }
